### Name: VPdtw
### Title: Variable Penalty Dynamic Time Warping function
### Aliases: VPdtw print.VPdtw plot.VPdtw
### Keywords: methods

### ** Examples

  ## Citation
  citation("VPdtw")

  ## Basic Examples of zero-penalty DTW

  ## Example of exact fit in the middle
  query <- c(1,5,4,3,9,8,5,2,6,5,4)
  reference <- c(rnorm(5),query,rnorm(5))
  lambda <- rep(0,length(reference))
  maxshift <- 11
  res <- VPdtw(reference,query,lambda,maxshift)
  plot(res)
  res

  ## Example of exact fit on one side
  reference <- c(1,5,4,3,9,8,5,2,6,5,4)
  query <- c(rnorm(5),reference)
  reference <- c(reference,rnorm(5))
  lambda <- rep(0,length(reference))
  maxshift <- 6
  res <- VPdtw(reference,query,lambda,maxshift)
  plot(res)
  res

  ## Example of exact fit on the other side
  reference <- c(1,5,4,3,9,8,5,2,6,5,4)
  query <- c(reference,rnorm(5))
  reference <- c(rnorm(5),reference)
  lambda <- rep(0,length(reference))
  maxshift <- 6
  res <- VPdtw(reference,query,lambda,maxshift)
  plot(res)
  res

  ## Example of exact fit except where one query gets dropped and its all on one side
  reference <- c(1,5,4,3,9,8,5,2,6,5,4)
  query <- c(reference[1:5],20,reference[6:11])
  reference <- c(rnorm(5),reference)
  query <- c(query,rnorm(5))
  lambda <- rep(0,length(reference))
  maxshift <- 6
  res <- VPdtw(reference,query,lambda,maxshift)
  plot(res)
  res
  
## Examples that use penalty term. Examples with long signals

data(reference)
data(query)
## Do alignment on log scale
reference <- log(reference)
query <- log(query)

## VPdtw
result <- VPdtw(reference=reference[1:2500],query=query[1:2500],penalty=dilation(reference[1:2500],150)/4,maxshift=150)
plot(result)
result

## Zero penalty DTW
result2 <- VPdtw(reference=reference[1:2500],query=query[1:2500],penalty=rep(0,length(reference)),maxshift=150)
plot(result2)

## Try both penalties at the same time
penalty <- dilation(reference,350)/5
penalty <- cbind(penalty,rep(0,length(penalty)))

result <- VPdtw(reference,query,penalty=penalty,maxshift=350)
plot(result,"After")
plot(result,"Shift")
result

## All three plots at once
plot(result)




